#!/usr/bin/env python3
import os
import sys


for file_name in sys.argv[1:]:
    out_name = os.path.dirname(file_name) + "/new." + \
        os.path.basename(file_name)
    with open(file_name, "r") as f, open(out_name, "w") as o:
        indent = 0
        for line in f:
            line = line.strip()
            if not line:
                o.write("\n")
                continue

            if line.startswith("}") or line.count(")") > line.count("("):
                indent -= 1
            for _ in range(indent):
                o.write("\t")
            o.write(line)
            o.write("\n")
            if line.endswith("{") or line.count("(") > line.count(")"):
                indent += 1
        os.rename(out_name, file_name)



#!/usr/bin/env python3

from os import environ, path
from subprocess import call

prefix = environ.get('MESON_INSTALL_PREFIX', '/usr/local')
datadir = path.join(prefix, 'share')
destdir = environ.get('DESTDIR', '')

if not destdir:
    print('Updating icon cache...')
    icons_dir = path.join(datadir, 'icons', 'hicolor')
    call(['gtk-update-icon-cache', '-qtf', icons_dir])
    print("Installing new Schemas")
    schemas_dir =  path.join(datadir, 'glib-2.0', 'schemas')
    call(['glib-compile-schemas', schemas_dir])
    apps_dir =  path.join(datadir, 'applications')
    call(['update-desktop-database', apps_dir])
